@@ -376,6 +376,7 @@ OpsItemFilterKeyType = Literal[
     "ChangeRequestByTemplate",
     "CreatedBy",
     "CreatedTime",
+    "InsightByType",
     "LastModifiedTime",
     "OperationalData",
     "OperationalDataKey",
@@ -400,6 +401,7 @@ OpsItemStatusType = Literal[
     "Cancelling",
     "ChangeCalendarOverrideApproved",
     "ChangeCalendarOverrideRejected",
+    "Closed",
     "CompletedWithFailure",
     "CompletedWithSuccess",
     "Failed",
